@@ -18,11 +18,11 @@ if sys.modules["glchess"].installed_mode:
     UNFINISHED_FILE  = os.path.join(HISTORY_DIR, 'unfinished')
     LOCAL_AI_CONFIG  = os.path.join(DATA_DIR, 'ai.xml')
 else:
-    APP_DATA_DIR     = os.path.join('/home/thomas/svn/gnome-games', 'glchess', 'data')
-    ICON_DIR         = os.path.join('/home/thomas/svn/gnome-games', 'glchess', 'textures')
-    TEXTURE_DIR      = os.path.join('/home/thomas/svn/gnome-games', 'glchess', 'textures')
-    GLADE_DIR        = os.path.join('/home/thomas/svn/gnome-games', 'glchess', 'glade')
-    BASE_DIR         = os.path.join('/home/thomas/svn/gnome-games', 'glchess', 'data')
+    APP_DATA_DIR     = os.path.join('/home/jclinton/development/svn/GNOME_GAMES_2_21', 'glchess', 'data')
+    ICON_DIR         = os.path.join('/home/jclinton/development/svn/GNOME_GAMES_2_21', 'glchess', 'textures')
+    TEXTURE_DIR      = os.path.join('/home/jclinton/development/svn/GNOME_GAMES_2_21', 'glchess', 'textures')
+    GLADE_DIR        = os.path.join('/home/jclinton/development/svn/GNOME_GAMES_2_21', 'glchess', 'glade')
+    BASE_DIR         = os.path.join('/home/jclinton/development/svn/GNOME_GAMES_2_21', 'glchess', 'data')
     LOCALEDIR        = os.path.join(APP_DATA_DIR, 'locale')
     DATA_DIR         = os.path.expanduser('~/.gnome2/glchess/')
     LOG_DIR          = os.path.join(DATA_DIR, 'logs')
@@ -40,7 +40,7 @@ import gtk.glade
 gtk.glade.bindtextdomain(DOMAIN, LOCALEDIR)
 gtk.glade.textdomain(DOMAIN)
 
-VERSION   = "2.21.5"
+VERSION   = "2.21.90"
 APPNAME   = _("glChess")
 ICON_NAME = 'gnome-glchess'
 
@@ -48,7 +48,8 @@ COPYRIGHT     = _('Copyright 2005-2007 Robert Ancell (and contributors)')
 DESCRIPTION   = _('The 2D/3D chess game for GNOME. \n\nglChess is a part of GNOME Games.')
 WEBSITE       = 'http://www.gnome.org/projects/gnome-games/'
 WEBSITE_LABEL = _('GNOME Games web site')
-AUTHORS       = ['Robert Ancell <bob27@users.sourceforge.net>']
+AUTHORS       = ['Robert Ancell <bob27@users.sourceforge.net>\n'
+		 'Andreas Røsdal <andreasr@gnome.org>']
 ARTISTS       = ['John-Paul Gignac (3D Models)', 'Max Froumentin (2D Models)', 'Hylke Bons <h.bons@student.rug.nl> (icon)']
 
 # The GPL license string will be translated, and the game name inserted.
